==> haskell-invariant-0.6.4-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 invariant
version:              0.6.4
visibility:           public
id:                   invariant-0.6.4-LSwPviTKjBYBj0GvyYmei8
key:                  invariant-0.6.4-LSwPviTKjBYBj0GvyYmei8
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  9bb976f44e8ede8e71b1634d771f69f8
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.4-LSwPviTKjBYBj0GvyYmei8
depends:
    StateVar-1.2.2-2qg6a9t7WOj8KHyna31Hkh array-0.5.4.0 base-4.17.2.1
    bifunctors-5.6.2-ASXTwgeHUT09TqDX9FqnHc
    comonad-5.0.9-Ar7cnVEb1Pi60zh00XTpgG containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    profunctors-5.6.3-H3aGaptwIhVL5gQLua9Hf2 stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-6WajAJaPEOH3f3auRxdjt7

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.6.4-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 invariant
version:              0.6.4
visibility:           public
id:                   invariant-0.6.4-4rxCqe9S0q5DRxj7mffGe2
key:                  invariant-0.6.4-4rxCqe9S0q5DRxj7mffGe2
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  80ebda19de320d18bfaa0adf97be16d6
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/invariant-0.6.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.4-4rxCqe9S0q5DRxj7mffGe2
depends:
    StateVar-1.2.2-2qg6a9t7WOj8KHyna31Hkh array-0.5.4.0 base-4.17.2.1
    bifunctors-5.6.2-2wjKnuEOJQ2FcD6QGPTr8J
    comonad-5.0.9-F3uF2UZEfOQ4mXlrEuQWeg containers-0.6.7
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    profunctors-5.6.3-FiHazNoTbSuEkaVv0xHC9t stm-2.5.1.0
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-Eo1ocpXri5ABLOF81VToPu

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
